abctools.AbjadObject
====================

.. abjad-lineage:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject

.. autoclass:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__eq__
   :noindex:

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__ge__
   :noindex:

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__gt__
   :noindex:

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__le__
   :noindex:

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__lt__
   :noindex:

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__ne__
   :noindex:

.. automethod:: abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject.__repr__
   :noindex:
